package com.cultural.heritage.controller.address;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.dto.CommonRequest;
import com.cultural.heritage.model.dto.address.AddressAddRequest;
import com.cultural.heritage.model.dto.address.AddressUpdateRequest;
import com.cultural.heritage.model.entity.Address;
import com.cultural.heritage.service.address.AddressService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/address")
@Slf4j
@Tag(name = "地址接口")
public class AddressController {


    @Resource
    private AddressService addressService;


    /**
     * 添加地址信息
     * @param addressAddRequest  地址添加请求体
     * @return  是否添加成功
     */
    @PostMapping("/add")
    public BaseResponse<Boolean> addAddress(@RequestBody AddressAddRequest addressAddRequest) {
        if (addressAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Address address = new Address();
        BeanUtils.copyProperties(addressAddRequest, address);
        boolean save = addressService.save(address);
        if (!save) {
            throw new BusinessException(ErrorCode.OPERATION_ERROR);
        }
        return ResultUtils.success(true);
    }



    /**
     * 删除地址信息
     * @param deleteRequest   地址删除请求体
     * @return  是否成功删除
     */
    @PostMapping("/delete")
    public BaseResponse<Boolean> delAddress(@RequestBody CommonRequest deleteRequest) {
        if (deleteRequest == null || deleteRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = deleteRequest.getId();
        boolean result = addressService.removeById(id);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }




    /**
     * 更新地址信息
     * @param addressUpdateRequest  地址更新请求体
     * @return 是否更新成功
     */
    @PostMapping("/update")
    public BaseResponse<Boolean> updateAddress(@RequestBody AddressUpdateRequest addressUpdateRequest) {
        if (addressUpdateRequest == null || addressUpdateRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Address address = new Address();
        BeanUtils.copyProperties(addressUpdateRequest, address);
        System.out.println(address);
        boolean result = addressService.updateById(address);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }




    /**
     * 查询用户地址信息
     * @param addressQueryRequest  地址查询请求体
     * @return 用户地址列表
     */
    @PostMapping("/list")
    public BaseResponse<List<Address>> listAddress(@RequestBody CommonRequest addressQueryRequest) {
        if (addressQueryRequest == null || addressQueryRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = addressQueryRequest.getId();
        QueryWrapper<Address> addressQueryWrapper = new QueryWrapper<>();
        addressQueryWrapper.eq("userId", id);
        List<Address> list = addressService.list(addressQueryWrapper);
        if (CollectionUtils.isEmpty(list)) {
            list = new ArrayList<>();
        }
        return ResultUtils.success(list);
    }



}
