package com.cultural.heritage.controller.good;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.dto.CommonDelBatchRequest;
import com.cultural.heritage.model.dto.CommonRequest;
import com.cultural.heritage.model.dto.good.GoodAddRequest;
import com.cultural.heritage.model.dto.good.GoodQueryRequest;
import com.cultural.heritage.model.dto.good.GoodUpdateRequest;
import com.cultural.heritage.model.entity.Good;
import com.cultural.heritage.service.good.CategoryService;
import com.cultural.heritage.service.good.GoodService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 商品接口
 */
@RestController
@RequestMapping("/goods")
@Slf4j
@Tag(name = "商品接口")
public class GoodController {

    @Resource
    private GoodService goodService;


    @Resource
    private CategoryService categoryService;


    /**
     * 添加商品
     * @param goodAddRequest  商品添加请求体
     * @return
     */
    @PostMapping("/add")
//    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Boolean> addGood(@RequestBody GoodAddRequest goodAddRequest) {
        if (goodAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Good good = new Good();
        BeanUtils.copyProperties(goodAddRequest, good);
        boolean save = goodService.save(good);
        if (!save) {
            throw new BusinessException(ErrorCode.SYSTEM_ERROR);
        }
        return ResultUtils.success(true, "商品插入成功");
    }


    /**
     * 删除商品
     * @param deleteRequest   商品删除请求体
     * @return  是否删除成功
     */
    @PostMapping("/delete")
//    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Boolean> deleteGood(@RequestBody CommonRequest deleteRequest) {
        if (deleteRequest == null || deleteRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        boolean result = goodService.removeById(deleteRequest.getId());
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }


    /**
     * 更新商品
     * @param goodUpdateRequest  商品更新请求体
     * @return  是否更新成功
     */
    @PostMapping("/update")
//    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Boolean> updateGoods(@RequestBody GoodUpdateRequest goodUpdateRequest) {
        if (goodUpdateRequest == null || goodUpdateRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Good good = new Good();
        BeanUtils.copyProperties(goodUpdateRequest, good);
        boolean result = goodService.updateById(good);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }




    /**
     * 分页获取商品列表
     * @param goodQueryRequest  查询商品请求体
     * @return  商品信息列表
     */
    @PostMapping("/list/page")
//    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Page<Good>> listGoodByPage(@RequestBody GoodQueryRequest goodQueryRequest) {
        long current = goodQueryRequest.getCurrent();
        long pageSize = goodQueryRequest.getPageSize();
        QueryWrapper<Good> goodQueryWrapper = goodService.getGoodQueryWrapper(goodQueryRequest);
        Page<Good> page = goodService.page(new Page<>(current, pageSize), goodQueryWrapper);
        return ResultUtils.success(page);
    }




    /**
     * 批量删除商品
     * @param commonDelBatchRequest 批量删除请求体
     * @return 是否批量删除成功
     */
    @PostMapping("/delBatch")
//    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Boolean> delBatchGoods(@RequestBody CommonDelBatchRequest commonDelBatchRequest) {
        List<Integer> idList = commonDelBatchRequest.getIdList();
        boolean result = goodService.removeBatchByIds(idList);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }



}
